<?php

namespace backend\controllers;
use Yii;
use backend\models\Product;
use backend\models\Category;
use backend\models\ProductSearch;
use backend\models\Country;
use backend\models\UserSearch;
use yii\filters\AccessControl;
use yii\web\Controller;
use yii\web\NotFoundHttpException;
use yii\filters\VerbFilter;
use yii\web\UploadedFile;
use yii\helpers\Url;

class ProductController extends Controller {
    /**
     * @inheritdoc
     */
    public function behaviors() {
        return [
            'verbs' => [
                'class' => VerbFilter::className(),
                'actions' => [
                    'delete' => ['POST'],
                ],
            ],
        ];
    }
    
    public function actionIndex() {
        $searchModel = new ProductSearch();
        $dataProvider = $searchModel->search(Yii::$app->request->queryParams);
        return $this->render('index', [
                    'searchModel' => $searchModel,
                    'dataProvider' => $dataProvider,
        ]);
    }
    public function actionView($id) {
        return $this->render('view', [
                    'model' => $this->findModel($id),
        ]);
    }
    public function actionCreate() {
        $model = new Product();
        $categories = Category::find()->all();
        if ($model->load(Yii::$app->request->post())) {
            $model->imageFile = UploadedFile::getInstance($model, 'product_thumb');
            if ($user = $model->addproduct()) {
                Yii::$app->session->setFlash('success', 'Product added successfully..');
                return $this->redirect(['index', 'id' => $model->id]);
            }
        }
        return $this->render('create', [
                    'model' => $model,
                    'categories' => $categories,
        ]);
    }
    public function actionUpdate($id) {
        $model = new Product();
        $model = $this->findModel($id);
        $categories = Category::find()->all();
        $oldProductFile = $model->getProductImgFile();
        $oldProductUrl = $model->getProductImgUrl();
        //echo "hi".$oldProductFile;
        if ($model->load(Yii::$app->request->post())) {
            $image = $model->uploadProductImg();
            if ($image === false && !empty($oldProductUrl)) {
                $model->product_thumb = $oldProductUrl;
            }
            if ($model->save()) {
                if ($image !== false) {
                    if (!empty($oldProductFile) && file_exists($oldProductFile)) {
                        unlink($oldProductFile);
                    }
                    $path = $model->getProductImgFile();
                    $image->saveAs($path);
                }
                Yii::$app->session->setFlash('success', 'Product Updated Successfully..');
                return $this->redirect(['index', 'id' => $model->id]);
            }
        } else {
            return $this->render('update', [
                        'model' => $model,
                        'categories' => $categories,
            ]);
        }
    }
    //get order list
    public function actionOrderList() {
        $searchModel = new ProductSearch();
        $dataProvider = $searchModel->getorders(Yii::$app->request->queryParams);
        return $this->render('order', [
                    'searchModel' => $searchModel,
                    'dataProvider' => $dataProvider,
        ]);
    }
    //view order list view
    public function actionOrderView($id) {
        $model = new Product();
        $orderData = $model->getorderbyid($id);
        //echo "<pre>";print_r($orderData);exit;
        return $this->render('orderview', [
                    'model' => $id,
                    'orderData' => $orderData,
        ]);
    }
    //delete order
    public function actionOrderDelete($id) {
        $model = new Product();
        $orderDelete = $model->orderdelete($id);
        Yii::$app->session->setFlash('success', 'Order Deleted Successfully..');
        return $this->redirect(['product/order-list']);
    }
    public function actionDelete($id) {
        $this->findModel($id)->delete();
        Yii::$app->session->setFlash('success', 'Product Deleted Successfully..');
        return $this->redirect(['index']);
    }
    protected function findModel($id) {
        if (($model = Product::findOne($id)) !== null) {
            return $model;
        } else {
            throw new NotFoundHttpException('The requested page does not exist.');
        }
    }    

}
