<?php

namespace backend\models;
use yii\db\Expression;
use yii\bootstrap\Modal;
use yii\db\ActiveRecord;
use Yii;

class User extends \yii\db\ActiveRecord
{
    const STATUS_DELETED = 0;
    const STATUS_ACTIVE = 10;
    /**
     * @inheritdoc
     */
    public static function tableName()
    {
        return 'user';
    }
    /**
     * @inheritdoc
     */
    public $confirm_password;
    public $old_password;
    public $new_password;
    public $repeat_password;
    public $password_hash;
    //public $cons;

    public function rules()
    {
        return [
            array('old_password, new_password, repeat_password', 'required', 'on' => 'changePwd'),
        array('old_password', 'findPasswords', 'on' => 'changePwd'),
        array('repeat_password', 'compare', 'compareAttribute'=>'new_password', 'on'=>'changePwd'),
            [['email','username'], 'required'],
            [['password_hash'],'safe'],
            ['email', 'email'],
            [['email'], 'unique'],
            ['id','safe'],
//            ['password_hash', 'string', 'min' => 6],
              //['confirm_password', 'compare', 'compareAttribute'=>'password_hash', 'message'=>"Passwords don't match"],
//            ['confirm_password', 'compare', 'compareAttribute'=>'password_hash', 'operator' => '!='],
//            [['password_hash'], 'required'], //ajax is not working
            ['username', 'unique', 'message' => '{attribute}:{value} already exists!'],
            [['created_at','updated_at'], 'safe'],
        ];
    }
   
    
    public function attributeLabels()
    {
        return [
            'password_hash' => 'Password',
        ];
    }
    public function adduser()
    {
        if (!$this->validate()) {
            return null;
        }
        $user = new User();
        $user->username = $this->username;
        $user->email = $this->email;
        $user->status = '10';
        $user->created_at = date('Y:m:d H:i:s');
        $user->updated_at = date('Y:m:d H:i:s');
        $user->setPassword($this->password_hash);
        $user->generateAuthKey();
        $user->save() ? $user : null;
        return true;
    }    
    public function setPassword($password)
    {
        $this->password_hash = Yii::$app->security->generatePasswordHash($password);
    }
    public function generateAuthKey()
    {
        $this->auth_key = Yii::$app->security->generateRandomString();
    }
    public static function findByPasswordResetToken($token)
    {
        if (!static::isPasswordResetTokenValid($token)) {
            return null;
        }

        return static::findOne([
            'password_reset_token' => $token,
            'status' => self::STATUS_ACTIVE,
        ]);
    }
    public static function isPasswordResetTokenValid($token)
    {
        if (empty($token)) {
            return false;
        }

        $timestamp = (int) substr($token, strrpos($token, '_') + 1);
        $expire = Yii::$app->params['user.passwordResetTokenExpire'];
        return $timestamp + $expire >= time();
    }
   
}
?>
