<?php

namespace frontend\models;
use Yii;
//session_start();
class Cart extends \yii\db\ActiveRecord
{
     protected $cart_contents = array();
     public function __construct() {
        // get the shopping cart array from the session
        $this->cart_contents = !empty($_SESSION['cart_contents'])?$_SESSION['cart_contents']:NULL;
		if ($this->cart_contents === NULL) {
			// set some base values
			$this->cart_contents = array('cart_total' => 0, 'total_items' => 0);
		}
    }
    public static function tableName() {
        return 'product';
    }
     public function getProductList() {
        $productList = (new \yii\db\Query())
                ->from('product')
                ->all();
       return $productList; 
    }
    public function rules() {
        return [
            [['description','id'], 'safe'],
            [['name'],'safe'],
            [['price'], 'safe'],
            [['product_thumb'], 'file', 'extensions'=>'jpg, gif, png'],
        ];
    }
    public function attributeLabels()
    {
        return [
            //'password_hash' => 'Password',
        ];
    }
    public function getProductById($productId) {
        $productItem = (new \yii\db\Query)
                ->from('product')
                ->where(['id' => $productId])
                ->one();
        return $productItem; 
    }
    
    public function insertitem($item = array()) {
        if (!is_array($item) OR count($item) === 0) {
            return FALSE;
        } else {
            if (!isset($item['id'], $item['name'], $item['price'], $item['qty'])) {
                return FALSE;
            } else {
                /*
                 * Insert Item
                 */
                // prep the quantity
                $item['qty'] = (float) $item['qty'];
                if ($item['qty'] == 0) {
                    return FALSE;
                }
                // prep the price
                $item['price'] = (float) $item['price'];
                // create a unique identifier for the item being inserted into the cart
                $rowid = md5($item['id']);
                // get quantity if it's already there and add it on
                $old_qty = isset($this->cart_contents[$rowid]['qty']) ? (int) $this->cart_contents[$rowid]['qty'] : 0;
                // re-create the entry with unique identifier and updated quantity
                $item['rowid'] = $rowid;
                $item['qty'] += $old_qty;
                $this->cart_contents[$rowid] = $item;
                // save Cart Item
                if ($this->save_cart()) {
                    //return count($this->contents());
                    return isset($rowid) ? $rowid : TRUE;
                } else {
                    return FALSE;
                }
            }
        }
    }
    public function updateitem($item = array()){
        //echo "<pre>";print_r($item); exit;
        if (!is_array($item) OR count($item) === 0) {
            return FALSE;
        } else {
            if (!isset($item['rowid'], $this->cart_contents[$item['rowid']])) {
                return FALSE;
            } else {
                // prep the quantity
                if (isset($item['qty'])) {
                    $item['qty'] = (float) $item['qty'];
                    // remove the item from the cart, if quantity is zero
                    if ($item['qty'] == 0) {
                        unset($this->cart_contents[$item['rowid']]);
                        return TRUE;
                    }
                }
                // find updatable keys
                $keys = array_intersect(array_keys($this->cart_contents[$item['rowid']]), array_keys($item));
                // prep the price
                if (isset($item['price'])) {
                    $item['price'] = (float) $item['price'];
                }
                // product id & name shouldn't be changed
                foreach (array_diff($keys, array('id', 'name')) as $key) {
                    $this->cart_contents[$item['rowid']][$key] = $item[$key];
                }
                // save cart data
                $this->save_cart();
                return TRUE;
            }
        }
    }
    public function remove($row_id) {
        // unset & save
        unset($this->cart_contents[$row_id]);
        $this->save_cart();
        return TRUE;
    }
    public function addplaceorder($total) {
        $user_type = $_SESSION['sessCustomerID']=='0' ? 'guest User' : 'authenticated user';
        $insertOrder = Yii::$app->db->createCommand()->insert('orders', ['user_id' => $_SESSION['sessCustomerID'], 'total_price' => $total,'user_type' => $user_type, 'created' => date('Y-m-d H:i:s'), 'modified' => date('Y-m-d H:i:s')])->execute();
        if($insertOrder){
            $orderID = Yii::$app->db->getLastInsertID();
            $sql = '';
            // get cart items
            $cartItems = $this->contents();
            foreach($cartItems as $item){
                $sql.= Yii::$app->db->createCommand()->insert('order_items', ['order_id' => $orderID, 'product_id' => $item['id'], 'quantity' => $item['qty']])->execute();
            }
            // insert order items into database
            //$insertOrderItems = $db->multi_query($sql);
            if($sql){
                $this->destroy();
                return $orderID;
            }else{
                return FALSE;
            }
        }else{
            return FALSE;
        }
    }
    public function addbillingdata($billingData) {
        Yii::$app->db->createCommand()->insert('billingdetails', $billingData)->execute();
        return true;
    }
    public function destroy(){
        $this->cart_contents = array('cart_total' => 0, 'total_items' => 0);
        unset($_SESSION['cart_contents']);
    }
    public function contents(){
        //rearrange the newest first
        $cart = array_reverse($this->cart_contents);
        //remove these so they don't create a problem when showing the cart table
        unset($cart['total_items']);
        unset($cart['cart_total']);
        return $cart;
    }
    public function total_items(){
        return $this->cart_contents['total_items'];
    }
    public function total() {
        return $this->cart_contents['cart_total'];
    }
    protected function save_cart() {
        $this->cart_contents['total_items'] = $this->cart_contents['cart_total'] = 0;
        foreach ($this->cart_contents as $key => $val) {
            // make sure the array contains the proper indexes
            if (!is_array($val) OR ! isset($val['price'], $val['qty'])) {
                continue;
            }
            $this->cart_contents['cart_total'] += ($val['price'] * $val['qty']);
            $this->cart_contents['total_items'] += $val['qty'];
            $this->cart_contents[$key]['subtotal'] = ($this->cart_contents[$key]['price'] * $this->cart_contents[$key]['qty']);
        }
        // if cart empty, delete it from the session
        if (count($this->cart_contents) <= 2) {
            unset($_SESSION['cart_contents']);
            return FALSE;
        } else {
            $_SESSION['cart_contents'] = $this->cart_contents;
            return TRUE;
        }
    }

}